==> jc-1.4.0.tar.gz: java/rmi/server/RMIClassLoader__24MyClassLoader.h <==
// class java.rmi.server.RMIClassLoader$MyClassLoader

// class file dependencies
// @dep_class 26b8d7b7a241db31 java_lang_ClassLoader
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7475ebc6fa299754 java_net_URLClassLoader
// @dep_class d76295f6e34832af java_rmi_server_RMIClassLoader__24MyClassLoader
// @dep_class 50a05c4401dcb8be java_security_SecureClassLoader

// header file dependencies
// @dep_header java_net_URLClassLoader

#include "java/net/URLClassLoader.h"

#ifndef _JC_java_rmi_server_RMIClassLoader__24MyClassLoader_H_
#define _JC_java_rmi_server_RMIClassLoader__24MyClassLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object;

typedef const struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$_init$dac6f9c2ae72ecdf(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *);
extern void _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$_init$0e85412cebaa57ea(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$getClassAnnotation$537df1ef71b55f46(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method_info$getClassAnnotation$537df1ef71b55f46;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$urlToAnnotation$580ee6f75dee9650(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods {
	struct _jc_java_lang_String$object	*(*getClassAnnotation$537df1ef71b55f46)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *);
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ClassLoader$vmethods	java_lang_ClassLoader;
	_jc_java_security_SecureClassLoader$vmethods	java_security_SecureClassLoader;
	_jc_java_net_URLClassLoader$vmethods	java_net_URLClassLoader;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods	java_rmi_server_RMIClassLoader__24MyClassLoader;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs {
	struct _jc_java_lang_String$object	*annotation;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs {
    _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs	java_rmi_server_RMIClassLoader__24MyClassLoader;
    _jc_java_net_URLClassLoader$sub_refs	java_net_URLClassLoader;
    _jc_java_security_SecureClassLoader$sub_refs	java_security_SecureClassLoader;
    _jc_java_lang_ClassLoader$sub_refs	java_lang_ClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ClassLoader$sub_nonrefs	java_lang_ClassLoader;
    _jc_java_security_SecureClassLoader$sub_nonrefs	java_security_SecureClassLoader;
    _jc_java_net_URLClassLoader$sub_nonrefs	java_net_URLClassLoader;
    _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs	java_rmi_server_RMIClassLoader__24MyClassLoader;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object {
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoader__24MyClassLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoader__24MyClassLoader_H_ */

==> jc-1.4.5.tar.gz: java/rmi/server/RMIClassLoader__24MyClassLoader.h <==
// class java.rmi.server.RMIClassLoader$MyClassLoader

// class file dependencies
// @dep_class 58c6b9c5ce1fc756 java_lang_ClassLoader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f9753be73caf5b06 java_net_URLClassLoader
// @dep_class d76295f6e34832af java_rmi_server_RMIClassLoader__24MyClassLoader
// @dep_class 50a05c4401dcb8be java_security_SecureClassLoader

// header file dependencies
// @dep_header java_net_URLClassLoader

#include "java/net/URLClassLoader.h"

#ifndef _JC_java_rmi_server_RMIClassLoader__24MyClassLoader_H_
#define _JC_java_rmi_server_RMIClassLoader__24MyClassLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object;

typedef const struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$_init$dac6f9c2ae72ecdf(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$_init$0e85412cebaa57ea(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$getClassAnnotation$537df1ef71b55f46(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method_info$getClassAnnotation$537df1ef71b55f46;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$method$urlToAnnotation$580ee6f75dee9650(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods {
	struct _jc_java_lang_String$object	*(*getClassAnnotation$537df1ef71b55f46)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ClassLoader$vmethods	java_lang_ClassLoader;
	_jc_java_security_SecureClassLoader$vmethods	java_security_SecureClassLoader;
	_jc_java_net_URLClassLoader$vmethods	java_net_URLClassLoader;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vmethods	java_rmi_server_RMIClassLoader__24MyClassLoader;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs {
	struct _jc_java_lang_String$object	*annotation;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs {
    _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_refs	java_rmi_server_RMIClassLoader__24MyClassLoader;
    _jc_java_net_URLClassLoader$sub_refs	java_net_URLClassLoader;
    _jc_java_security_SecureClassLoader$sub_refs	java_security_SecureClassLoader;
    _jc_java_lang_ClassLoader$sub_refs	java_lang_ClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ClassLoader$sub_nonrefs	java_lang_ClassLoader;
    _jc_java_security_SecureClassLoader$sub_nonrefs	java_security_SecureClassLoader;
    _jc_java_net_URLClassLoader$sub_nonrefs	java_net_URLClassLoader;
    _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$sub_nonrefs	java_rmi_server_RMIClassLoader__24MyClassLoader;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object {
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoader__24MyClassLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$vtype _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoader__24MyClassLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoader__24MyClassLoader_H_ */
